@@ -3,5 +3,10 @@
 from .VHDLTest import VHDLTest
 
 
-if __name__ == '__main__':
+def main() -> None:
+    """Run the VHDLTest class."""
     VHDLTest().run()
+
+
+if __name__ == '__main__':
+    main()
